.. index::
    single: pdistreport; --help

.. _pdistreport_script:

.. autoprogram:: pyramid.scripts.pdistreport:get_parser()
    :prog: pdistreport

.. seealso:: :ref:`showing_distributions` and :ref:`running-pscripts`.
